@@ -26,14 +26,12 @@
 
 BOOL cmd_exit(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-    
-    if(sCommand_option_item(command, "-force")) {
+    if(sRunInfo_option(runinfo, "-force")) {
         runinfo->mRCode = RCODE_EXIT;
     }
     else {
         if(vector_count(gJobs) > 0) {
-            err_msg("jobs exist", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("jobs exist", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             return FALSE;
         }
 
@@ -45,14 +43,13 @@ BOOL cmd_exit(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_while(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-    if(command->mBlocksNum == 2) {
+    if(runinfo->mBlocksNum == 2) {
         runinfo->mRCode = 0;
 
         while(1) {
             /// condition ///
             int rcode;
-            if(!run(command->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+            if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                 runinfo->mRCode = rcode;
                 return FALSE;
             }
@@ -62,7 +59,7 @@ BOOL cmd_while(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
 
             /// inner loop ///
-            if(!run(command->mBlocks[1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+            if(!run(runinfo->mBlocks[1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                 if(rcode == RCODE_BREAK) {
                     rcode = 0;
                     break;
@@ -82,11 +79,9 @@ BOOL cmd_while(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_for(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mBlocksNum == 1 && command->mArgsNumRuntime >= 4) {
-        char* arg_name = command->mArgsRuntime[1];
-        char* in = command->mArgsRuntime[2];
+    if(runinfo->mBlocksNum == 1 && runinfo->mArgsNumRuntime >= 4) {
+        char* arg_name = runinfo->mArgsRuntime[1];
+        char* in = runinfo->mArgsRuntime[2];
 
         if(strcmp(in, "in") != 0) {
             err_msg("for command needs 'in' word at 3th argument.", runinfo->mSName, runinfo->mSLine, "for");
@@ -98,13 +93,13 @@ BOOL cmd_for(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         sObject* object = SFUN(runinfo->mRunningObject).mLocalObjects;
 
         int i;
-        for(i=3; i<command->mArgsNumRuntime; i++) {
+        for(i=3; i<runinfo->mArgsNumRuntime; i++) {
             /// condition ///
-            uobject_put(object, arg_name, STRING_NEW_GC(command->mArgsRuntime[i], TRUE));
+            uobject_put(object, arg_name, STRING_NEW_GC(runinfo->mArgsRuntime[i], TRUE));
 
             /// inner loop ///
             int rcode = 0;
-            if(!run(command->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+            if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                 if(rcode == RCODE_BREAK) {
                     rcode = 0;
                     break;
@@ -142,17 +137,15 @@ BOOL cmd_false(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_if(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mBlocksNum > 1) {
-        if(command->mBlocksNum % 2 == 0) {
+    if(runinfo->mBlocksNum > 1) {
+        if(runinfo->mBlocksNum % 2 == 0) {
             runinfo->mRCode = 0;
 
             int i;
-            for(i=0; i<command->mBlocksNum; i+=2) {
+            for(i=0; i<runinfo->mBlocksNum; i+=2) {
                 /// a condition ///
                 int rcode = 0;
-                if(!run(command->mBlocks[i], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                if(!run(runinfo->mBlocks[i], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                     runinfo->mRCode = rcode;
                     return FALSE;
                 }
@@ -160,7 +153,7 @@ BOOL cmd_if(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 /// a statment ///
                 if(rcode == 0) {
                     int rcode = 0;
-                    if(!run(command->mBlocks[i+1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                    if(!run(runinfo->mBlocks[i+1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                         runinfo->mRCode = rcode;
                         return FALSE;
                     }
@@ -175,10 +168,10 @@ BOOL cmd_if(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             BOOL run_else = TRUE;
 
             int i;
-            for(i=0; i<command->mBlocksNum-1; i+=2) {
+            for(i=0; i<runinfo->mBlocksNum-1; i+=2) {
                 /// a condition ///
                 int rcode = 0;
-                if(!run(command->mBlocks[i], nextin, nextout,  &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                if(!run(runinfo->mBlocks[i], nextin, nextout,  &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                     runinfo->mRCode = rcode;
                     return FALSE;
                 }
@@ -188,7 +181,7 @@ BOOL cmd_if(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     run_else = FALSE;
 
                     int rcode = 0;
-                    if(!run(command->mBlocks[i+1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                    if(!run(runinfo->mBlocks[i+1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                         runinfo->mRCode = rcode;
                         return FALSE;
                     }
@@ -200,7 +193,7 @@ BOOL cmd_if(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             /// else statment ///
             if(run_else) {
                 int rcode = 0;
-                if(!run(command->mBlocks[command->mBlocksNum-1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                if(!run(runinfo->mBlocks[runinfo->mBlocksNum-1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                     runinfo->mRCode = rcode;
                     return FALSE;
                 }
@@ -221,11 +214,9 @@ BOOL cmd_return(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_subshell(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mBlocksNum == 1) {
+    if(runinfo->mBlocksNum == 1) {
         int rcode = 0;
-        if(!run(command->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+        if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
             runinfo->mRCode = rcode;
             return FALSE;
         }
@@ -237,41 +228,39 @@ BOOL cmd_subshell(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
     sObject* out;
-    if(sCommand_option_item(command, "-out-to-error")) {
+    if(sRunInfo_option(runinfo, "-out-to-error")) {
         out = gStderr;
     }
     else {
         out = nextout;
     }
 
-    if(command->mArgsNumRuntime > 1) {
+    if(runinfo->mArgsNumRuntime > 1) {
         int i;
-        for(i=1; i<command->mArgsNumRuntime-1; i++) {
-            if(!fd_write(out, command->mArgsRuntime[i], strlen(command->mArgsRuntime[i]))) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        for(i=1; i<runinfo->mArgsNumRuntime-1; i++) {
+            if(!fd_write(out, runinfo->mArgsRuntime[i], strlen(runinfo->mArgsRuntime[i]))) {
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(out, " ", 1)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
         }
-        if(!fd_write(out, command->mArgsRuntime[i], strlen(command->mArgsRuntime[i]))) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        if(!fd_write(out, runinfo->mArgsRuntime[i], strlen(runinfo->mArgsRuntime[i]))) {
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
         runinfo->mRCode = 0;
     }
     else if(runinfo->mFilter) {
-        if(sCommand_option_item(command, "-read-from-error")) {
+        if(sRunInfo_option(runinfo, "-read-from-error")) {
             if(!fd_write(out, SFD(gStderr).mBuf, SFD(gStderr).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -279,7 +268,7 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else {
             if(!fd_write(out, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -298,17 +287,15 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_try(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mBlocksNum == 2) {
+    if(runinfo->mBlocksNum == 2) {
         int rcode = 0;
-        if(!run(command->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+        if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
             if(rcode == RCODE_NFUN_FALSE || rcode == RCODE_BREAK || rcode == RCODE_RETURN || rcode == RCODE_EXIT) {
                 runinfo->mRCode = rcode;
                 return FALSE;
             }
             else {
-                if(!run(command->mBlocks[1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                if(!run(runinfo->mBlocks[1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                     runinfo->mRCode = rcode;
                     return FALSE;
                 }
@@ -329,9 +316,8 @@ BOOL cmd_try(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_errmsg(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
     if(!fd_write(nextout, string_c_str(gErrMsg), string_length(gErrMsg))) {
-        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         return FALSE;
     }
@@ -342,10 +328,8 @@ BOOL cmd_errmsg(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_raise(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mArgsNumRuntime == 2) {
-        err_msg(command->mArgsRuntime[1], runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+    if(runinfo->mArgsNumRuntime == 2) {
+        err_msg(runinfo->mArgsRuntime[1], runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
         return FALSE;
     }
 
@@ -354,16 +338,14 @@ BOOL cmd_raise(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mArgsNumRuntime == 1) {
+    if(runinfo->mArgsNumRuntime == 1) {
         int num = gc_sweep();
 
         char buf[BUFSIZ];
         int size = snprintf(buf, BUFSIZ, "%d objects deleted\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -371,14 +353,14 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
     else {
         int i;
-        for(i=1; i<command->mArgsNumRuntime; i++) {
-            char* var_name = command->mArgsRuntime[i];
+        for(i=1; i<runinfo->mArgsNumRuntime; i++) {
+            char* var_name = runinfo->mArgsRuntime[i];
             sObject* current_object = runinfo->mCurrentObject;
 
             sObject* item = uobject_item(current_object, var_name);
 
             if(!IS_USER_OBJECT(item)) {
-                err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 return FALSE;
             }
 
@@ -397,10 +379,9 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_load(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-    if(command->mArgsNumRuntime >= 2) {
+    if(runinfo->mArgsNumRuntime >= 2) {
         runinfo->mRCode = 0;
-        if(!load_file(command->mArgsRuntime[1], nextin, nextout, runinfo, command->mArgsRuntime + 2, command->mArgsNumRuntime -2))
+        if(!load_file(runinfo->mArgsRuntime[1], nextin, nextout, runinfo, runinfo->mArgsRuntime + 2, runinfo->mArgsNumRuntime -2))
         {
             return FALSE;
         }
@@ -411,18 +392,17 @@ BOOL cmd_load(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-    if(command->mBlocksNum > 0) {
+    if(runinfo->mBlocksNum > 0) {
         int rcode;
-        if(!run(command->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-            err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+            err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = rcode;
             return FALSE;
         }
         runinfo->mRCode = rcode;
     }
-    else if(command->mArgsNumRuntime >= 2) {
-        char* buf = command->mArgsRuntime[1];
+    else if(runinfo->mArgsNumRuntime >= 2) {
+        char* buf = runinfo->mArgsRuntime[1];
 
         stack_start_stack();
         int rcode = 0;
@@ -432,14 +412,14 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         snprintf(buf2, BUFSIZ, "%s %d: eval", runinfo->mSName, runinfo->mSLine);
         if(parse(buf, buf2, &sline, block, NULL)) {
             if(!run(block, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = rcode;
                 stack_end_stack();
                 return FALSE;
             }
         }
         else {
-            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             stack_end_stack();
             return FALSE;
         }
@@ -460,14 +440,14 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         if(parse(buf, buf2, &sline, block, NULL)) {
             sObject* nextin2 = FD_NEW_STACK();
             if(!run(block, nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = rcode;
                 stack_end_stack();
                 return FALSE;
             }
         }
         else {
-            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             stack_end_stack();
             return FALSE;
         }
@@ -487,25 +467,22 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_msleep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mArgsNumRuntime == 2) {
-        /// Ω–Œœ ///
+    if(runinfo->mArgsNumRuntime == 2) {
         char c [] = {'.', 'o', 'O'};
-        int n = atoi(command->mArgsRuntime[1]);
+        int n = atoi(runinfo->mArgsRuntime[1]);
         int i;
         for(i=0; i < n*5; i++) {
             char buf[32];
             int size = snprintf(buf, 32, "%c\033[D", c[i % 3]);
 
             if(!fd_write(nextout, buf, size)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(nextout == gStdout) {
                 if(!fd_flash(nextout, 1)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -522,14 +499,12 @@ BOOL cmd_msleep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_stackinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
     char buf[BUFSIZ];
 
     int size = snprintf(buf, BUFSIZ, "slot size %d\npool size %d\nall object number %d\n", stack_slot_size(), stack_page_size(), stack_slot_size()*stack_page_size());
 
     if(!fd_write(nextout, buf, size)) {
-        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         return FALSE;
     }
@@ -540,7 +515,6 @@ BOOL cmd_stackinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_stackframe(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
     char buf[BUFSIZ];
 
     uobject_it* it = uobject_loop_begin(SFUN(runinfo->mRunningObject).mLocalObjects);
@@ -548,13 +522,13 @@ BOOL cmd_stackframe(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         sObject* object2 = uobject_loop_item(it);
         char* key = uobject_loop_key(it);
 
-        char*obj_kind[16] = {
-            NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "job", "object", "function", "class", "external program", "completion", "external object"
+        char* obj_kind[T_TYPE_MAX] = {
+            NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "file dicriptor", "job", "object", "function", "class", "external program", "completion", "external object"
         };
         int size = snprintf(buf, BUFSIZ, "%s: %s\n", key, obj_kind[TYPE(object2)]);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -617,7 +591,7 @@ BOOL cmd_funinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, BUFSIZ, "source name: %s\nsource line: %d\nrun nest level: %d\ncurrent object: %s\nreciever object: %s\ncommand name: %s\n", runinfo2->mSName, runinfo2->mSLine, runinfo2->mNestLevel, current_object, reciever_object, command_name);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -630,13 +604,12 @@ BOOL cmd_funinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_gcinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
     char buf[BUFSIZ];
 
     int size = snprintf(buf, BUFSIZ, "free objects %d\nused objects %d\nall object number %d\nslot size %d\npool size %d\n", gc_free_objects_num(), gc_used_objects_num(), gc_slot_size()*gc_pool_size(), gc_slot_size(), gc_pool_size());
 
     if(!fd_write(nextout, buf, size)) {
-        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         return FALSE;
     }
@@ -647,14 +620,12 @@ BOOL cmd_gcinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_time(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(command->mBlocksNum > 0) {
+    if(runinfo->mBlocksNum > 0) {
         time_t timer;
         time(&timer);
 
         int rcode;
-        if(!run(command->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+        if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
             runinfo->mRCode = rcode;
             return FALSE;
         }
@@ -671,7 +642,7 @@ BOOL cmd_time(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 1024, "%d sec(%d minuts %d sec)\n", sec, minuts, sec2);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -682,10 +653,8 @@ BOOL cmd_time(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_umask(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(!runinfo->mFilter && command->mArgsNumRuntime == 2) {
-        int number = strtol(command->mArgsRuntime[1], NULL, 8);
+    if(!runinfo->mFilter && runinfo->mArgsNumRuntime == 2) {
+        int number = strtol(runinfo->mArgsRuntime[1], NULL, 8);
         umask(number);
         runinfo->mRCode = 0;
     }
@@ -817,9 +786,8 @@ sObject* gPrompt;
 
 BOOL cmd_prompt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-    if(command->mBlocksNum == 1) {
-        gPrompt = block_clone_gc(command->mBlocks[0], T_BLOCK, FALSE);
+    if(runinfo->mBlocksNum == 1) {
+        gPrompt = block_clone_on_gc(runinfo->mBlocks[0], T_BLOCK, FALSE);
         uobject_put(gXyzshObject, "_prompt", gPrompt);
         runinfo->mRCode = 0;
     }
@@ -829,17 +797,16 @@ BOOL cmd_prompt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
     sObject* fun = runinfo->mRunningObject;
 
-    if(sCommand_option_item(command, "-number")) {
+    if(sRunInfo_option(runinfo, "-number")) {
         if(SFUN(fun).mArgBlocks) {
             char buf[32];
             int size = snprintf(buf, 32, "%d\n", vector_count(SFUN(fun).mArgBlocks));
 
             if(!fd_write(nextout, buf, size))
             {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -847,10 +814,10 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             runinfo->mRCode = 0;
         }
     }
-    else if(sCommand_option_item(command, "-run")) {
+    else if(sRunInfo_option(runinfo, "-run")) {
         int block_num;
-        if(command->mArgsNumRuntime > 1) {
-            block_num = atoi(command->mArgsRuntime[1]);
+        if(runinfo->mArgsNumRuntime > 1) {
+            block_num = atoi(runinfo->mArgsRuntime[1]);
         }
         else {
             block_num = 0;
@@ -862,8 +829,7 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             int rcode = 0;
             if(!run(block, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) 
             {
-                sCommand* command = runinfo->mCommand;
-                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = rcode;
                 return FALSE;
             }
@@ -871,8 +837,8 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
     else {
         int block_num;
-        if(command->mArgsNumRuntime > 1) {
-            block_num = atoi(command->mArgsRuntime[1]);
+        if(runinfo->mArgsNumRuntime > 1) {
+            block_num = atoi(runinfo->mArgsRuntime[1]);
         }
         else {
             block_num = 0;
@@ -883,7 +849,7 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             if(!fd_write(nextout, SBLOCK(block).mSource, strlen(SBLOCK(block).mSource)))
             {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -897,33 +863,31 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
-    if(sCommand_option_item(command, "-byte")) {
+    if(sRunInfo_option(runinfo, "-byte")) {
         gKanjiCode = kByte;
         runinfo->mRCode = 0;
     }
-    else if(sCommand_option_item(command, "-utf8")) {
+    else if(sRunInfo_option(runinfo, "-utf8")) {
         gKanjiCode = kUtf8;
         runinfo->mRCode = 0;
     }
-    else if(sCommand_option_item(command, "-sjis")) {
+    else if(sRunInfo_option(runinfo, "-sjis")) {
         gKanjiCode = kSjis;
         runinfo->mRCode = 0;
     }
-    else if(sCommand_option_item(command, "-eucjp")) {
+    else if(sRunInfo_option(runinfo, "-eucjp")) {
         gKanjiCode = kEucjp;
         runinfo->mRCode = 0;
     }
     else {
         if(gKanjiCode == kUtf8) {
             if(!fd_write(nextout, "utf8", 4)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -932,12 +896,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else if(gKanjiCode == kByte) {
             if(!fd_write(nextout, "byte", 4)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -946,12 +910,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else if(gKanjiCode == kSjis) {
             if(!fd_write(nextout, "sjis", 4)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -960,12 +924,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else if(gKanjiCode == kEucjp) {
             if(!fd_write(nextout, "eucjp", 5)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -979,21 +943,19 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_jobs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    sCommand* command = runinfo->mCommand;
-
     char buf[BUFSIZ];
     int i;
     for(i=0; i<vector_count(gJobs); i++) {
         sObject* job = vector_item(gJobs, i);
         int size = snprintf(buf, BUFSIZ, "[%d] %s (pgrp: %d)", i+1, SJOB(job).mName, SJOB(job).mPGroup);
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
 
         if(!fd_write(nextout, "\n", 1)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -1012,8 +974,8 @@ BOOL cmd_jobs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 BOOL cmd_fg(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     if(gAppType != kATOptC) {
-        if(runinfo->mCommand->mArgsNumRuntime >= 2) {
-            int num = atoi(runinfo->mCommand->mArgsRuntime[1]);
+        if(runinfo->mArgsNumRuntime >= 2) {
+            int num = atoi(runinfo->mArgsRuntime[1]);
             if(!forground_job(num-1)) {
                 return FALSE;
             }
