@@ -15,7 +15,24 @@ static void main_xyzsh_job_done(int job_num, char* job_title)
 int main(int argc, char** argv)
 {
     CHECKML_BEGIN(FALSE);
-
+/*
+printf("sObject %d\n", (int)sizeof(sObject));
+printf("string_obj %d\n", (int)sizeof(string_obj));
+printf("vector_obj %d\n", (int)sizeof(vector_obj));
+printf("hash_obj %d\n", (int)sizeof(hash_obj));
+printf("list_obj %d\n", (int)sizeof(list_obj));
+printf("fd_obj %d\n", (int)sizeof(fd_obj));
+printf("fd2_obj %d\n", (int)sizeof(fd2_obj));
+printf("job_obj %d\n", (int)sizeof(job_obj));
+printf("block_obj %d\n", (int)sizeof(struct block_obj));
+printf("uobject_obj %d\n", (int)sizeof(uobject_obj));
+printf("nfun_obj %d\n", (int)sizeof(nfun_obj));
+printf("fun_obj %d\n", (int)sizeof(fun_obj));
+printf("class_obj %d\n", (int)sizeof(class_obj));
+printf("completion_obj %d\n", (int)sizeof(completion_obj));
+printf("external_prog_obj %d\n", (int)sizeof(external_prog_obj));
+printf("external_obj %d\n", (int)sizeof(external_obj));
+*/
     srandom((unsigned)time(NULL));
 
     char* optc = NULL;
